"use strict";
/*
 * Copyright (C) 2017, 2018 TypeFox and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
const protocol_translation_1 = require("./protocol-translation");
const tsp_command_types_1 = require("./tsp-command-types");
function collectDocumentSymbols(parent, symbols) {
    let shouldInclude = shouldInclueEntry(parent);
    for (const span of parent.spans) {
        const range = protocol_translation_1.asRange(span);
        const children = [];
        if (parent.childItems) {
            for (const child of parent.childItems) {
                if (child.spans.some(span => !!protocol_translation_1.Range.intersection(range, protocol_translation_1.asRange(span)))) {
                    const includedChild = collectDocumentSymbols(child, children);
                    shouldInclude = shouldInclude || includedChild;
                }
            }
        }
        if (shouldInclude) {
            symbols.push({
                name: parent.text,
                detail: '',
                kind: protocol_translation_1.toSymbolKind(parent.kind),
                range,
                selectionRange: range,
                children
            });
        }
    }
    return shouldInclude;
}
exports.collectDocumentSymbols = collectDocumentSymbols;
function collectSymbolInformations(uri, parent, symbols) {
    let shouldInclude = shouldInclueEntry(parent);
    for (const span of parent.spans) {
        const range = protocol_translation_1.asRange(span);
        const children = [];
        if (parent.childItems) {
            for (const child of parent.childItems) {
                if (child.spans.some(span => !!protocol_translation_1.Range.intersection(range, protocol_translation_1.asRange(span)))) {
                    const includedChild = collectSymbolInformations(uri, child, children);
                    shouldInclude = shouldInclude || includedChild;
                }
            }
        }
        if (shouldInclude) {
            symbols.push({
                name: parent.text,
                kind: protocol_translation_1.toSymbolKind(parent.kind),
                location: {
                    uri,
                    range
                }
            });
            symbols.push(...children);
        }
    }
    return shouldInclude;
}
exports.collectSymbolInformations = collectSymbolInformations;
function shouldInclueEntry(item) {
    if (item.kind === tsp_command_types_1.ScriptElementKind.alias) {
        return false;
    }
    return !!(item.text && item.text !== '<function>' && item.text !== '<class>');
}
exports.shouldInclueEntry = shouldInclueEntry;
//# sourceMappingURL=document-symbol.js.map